@@ -15,6 +15,11 @@ function ibm_j2re_detect() {
 	    j2se_expected_min_size=37 #  bytes
 	    found=true
 	    ;;
+        "ibm-java2-jre-50-linux-i386.tgz") # SUPPORTED
+	    j2se_version=1.5.0
+	    j2se_expected_min_size=40 # 41655352 bytes
+	    found=true
+	    ;;
       esac
       ;;
     amd64|x86_64-linux)
@@ -24,6 +29,44 @@ function ibm_j2re_detect() {
 	    j2se_expected_min_size=37
 	    found=true
 	    ;;
+        "ibm-java2-jre-50-linux-x86_64.tgz") # SUPPORTED
+	    j2se_version=1.5.0
+	    j2se_expected_min_size=46 # 48018851 bytes
+	    found=true
+	    ;;
+      esac
+      ;;
+    powerpc|powerpc-linux)
+      case "$archive_name" in
+        "IBMJava2-JRE-131.ppc.tgz") # SUPPORTED
+	    j2se_version=1.3.1
+	    j2se_expected_min_size=20 #  bytes
+	    found=true
+	    ;;
+        "IBMJava2-JRE-142.ppc.tgz") # SUPPORTED
+	    j2se_version=1.4.2
+	    j2se_expected_min_size=40 #  bytes
+	    found=true
+	    ;;
+        "ibm-java2-jre-50-linux-ppc.tgz") # SUPPORTED
+	    j2se_version=1.5.0
+	    j2se_expected_min_size=42 # 43687702 bytes
+	    found=true
+	    ;;
+      esac
+      ;;
+    powerpc64|powerpc64-linux)
+      case "$archive_name" in
+        "IBMJava2-JRE-142.ppc64.tgz") # SUPPORTED
+	    j2se_version=1.4.2
+	    j2se_expected_min_size=37
+	    found=true
+	    ;;
+        "ibm-java2-jre-50-linux-ppc64.tgz") # SUPPORTED
+	    j2se_version=1.5.0
+	    j2se_expected_min_size=46 # 47734431 bytes
+	    found=true
+	    ;;
       esac
       ;;
     s390|s390-linux)
@@ -48,27 +91,14 @@ function ibm_j2re_detect() {
 	    j2se_expected_min_size=34
 	    found=true
 	    ;;
-      esac
-      ;;
-    powerpc|powerpc-linux)
-      case "$archive_name" in
-        "IBMJava2-JRE-131.ppc.tgz") # SUPPORTED
-	    j2se_version=1.3.1
-	    j2se_expected_min_size=20 #  bytes
+        "ibm-java2-jre-50-s390.tgz") # SUPPORTED
+	    j2se_version=1.5.0
+	    j2se_expected_min_size=42 # 43686815 bytes
 	    found=true
 	    ;;
-        "IBMJava2-JRE-142.ppc.tgz") # SUPPORTED
-	    j2se_version=1.4.2
-	    j2se_expected_min_size=40 #  bytes
-	    found=true
-	    ;;
-      esac
-      ;;
-    powerpc64|powerpc64-linux)
-      case "$archive_name" in
-        "IBMJava2-JRE-142.ppc64.tgz") # SUPPORTED
-	    j2se_version=1.4.2
-	    j2se_expected_min_size=37
+        "ibm-java2-jre-50-s390x.tgz") # SUPPORTED
+	    j2se_version=1.5.0
+	    j2se_expected_min_size=42 # 43773066 bytes
 	    found=true
 	    ;;
       esac
