@@ -15,6 +15,11 @@ function ibm_j2sdk_detect() {
 	    j2se_expected_min_size=49 # 56719533 bytes
 	    found=true
 	    ;;
+        "ibm-java2-sdk-50-linux-i386.tgz") # SUPPORTED
+	    j2se_version=1.5.0
+	    j2se_expected_min_size=56 # 58162719 bytes
+	    found=true
+	    ;;
       esac
       ;;
     amd64|x86_64-linux)
@@ -24,6 +29,11 @@ function ibm_j2sdk_detect() {
 	    j2se_expected_min_size=52
 	    found=true
 	    ;;
+        "ibm-java2-sdk-50-linux-x86_64.tgz") # SUPPORTED
+	    j2se_version=1.4.2
+	    j2se_expected_min_size=57 # 59706399 bytes
+	    found=true
+	    ;;
       esac
       ;;
     powerpc|powerpc-linux)
@@ -43,6 +53,11 @@ function ibm_j2sdk_detect() {
 	    j2se_expected_min_size=51 # 59313669 bytes
 	    found=true
 	    ;;
+        "ibm-java2-sdk-50-linux-ppc.tgz") # SUPPORTED
+	    j2se_version=1.5.0
+	    j2se_expected_min_size=61 # 63942070 bytes
+	    found=true
+	    ;;
       esac
       ;;
     powerpc64|powerpc64-linux)
@@ -51,11 +66,26 @@ function ibm_j2sdk_detect() {
 	    j2se_version=1.4.2
 	    j2se_expected_min_size=55
 	    found=true
+	    ;;   
+        "ibm-java2-jre-50-linux-ppc64.tgz") # SUPPORTED
+	    j2se_version=1.5.0
+	    j2se_expected_min_size=61 # 63942070 bytes
+	    found=true
 	    ;;
       esac
       ;;
     s390|s390-linux)
       case "$archive_name" in
+        "IBMJava2-SDK-131.s390.tgz") # SUPPORTED
+	    j2se_version=1.3.1
+	    j2se_expected_min_size=20
+	    found=true
+	    ;;
+        "IBMJava2-SDK-141.s390.tgz") # SUPPORTED
+	    j2se_version=1.4.1
+	    j2se_expected_min_size=51
+	    found=true
+	    ;;
         "IBMJava2-SDK-142.s390.tgz") # SUPPORTED
 	    j2se_version=1.4.2
 	    j2se_expected_min_size=52
@@ -66,14 +96,14 @@ function ibm_j2sdk_detect() {
 	    j2se_expected_min_size=52
 	    found=true
 	    ;;
-        "IBMJava2-SDK-141.s390.tgz") # SUPPORTED
-	    j2se_version=1.4.1
-	    j2se_expected_min_size=51
+        "ibm-java2-sdk-50-s390.tgz") # SUPPORTED
+	    j2se_version=1.5.0
+	    j2se_expected_min_size=57 # 59685647 bytes
 	    found=true
 	    ;;
-        "IBMJava2-SDK-131.s390.tgz") # SUPPORTED
-	    j2se_version=1.3.1
-	    j2se_expected_min_size=20
+        "ibm-java2-sdk-50-s390x.tgz") # SUPPORTED
+	    j2se_version=1.5.0
+	    j2se_expected_min_size=57 # 59773265 bytes
 	    found=true
 	    ;;
       esac
