@@ -13,7 +13,7 @@ Package: $j2se_package
 Architecture: any
 Depends: \${shlibs:Depends}
 Recommends: netbase, libx11-6 | xlibs, libasound2, libgtk1.2
-Provides: java-common, java-virtual-machine, java-runtime, java2-runtime, java-browser-plugin, j2re${j2se_release}
+Provides: java-virtual-machine, java-runtime, java2-runtime, java-browser-plugin, j2re${j2se_release}
 Replaces: ${j2se_package}debian
 Description: $j2se_title
  The Java(TM) 2 Runtime Environment contains the Java virtual machine,
