@@ -134,8 +134,11 @@ function j2se_build() {
     dh_installdocs
     # dh_install
     # dh_link
-    echo "    dh_compress"
-    dh_compress $( find "$install_dir/$j2se_base/man" -type f ! -name "*.gz" )
+    # Conditionally wrapping this as not all JRE/JDKs have man directories
+    if [ -e "$install_dir/$j2se_base/man" ]; then
+        echo "    dh_compress"
+        dh_compress $( find "$install_dir/$j2se_base/man" -type f ! -name "*.gz" )
+    fi
     echo "    dh_fixperms"
     dh_fixperms
     echo "    dh_installdeb"
