@@ -7,32 +7,32 @@ local found=
       case "$archive_name" in
 	"j2re-1_4_1_"[0-9][0-9]"-linux-i586.bin") # SUPPORTED
 	    j2se_version="1.4.1+${archive_name:11:2}"
-	    j2se_expected_min_size=54 # 55392 kB
+	    j2se_expected_min_size=14 # 14378891 bytes
 	    found=true
 	    ;;
 	"j2re-1_4_2-linux-i586.bin") # SUPPORTED
 	    j2se_version=1.4.2
-	    j2se_expected_min_size=56 # 58000 kB
+	    j2se_expected_min_size=14 # 14378891 bytes
 	    found=true
 	    ;;
 	"j2re-1_4_2_"[0-9][0-9]"-linux-i586.bin") # SUPPORTED
 	    j2se_version="1.4.2+${archive_name:11:2}"
-	    j2se_expected_min_size=56 # 58093 kB
+	    j2se_expected_min_size=15 # 14378891 bytes
 	    found=true
 	    ;;
 	"j2re-1_5_0-beta2-linux-i586.bin") # SUPPORTED
 	    j2se_version=1.5.0+beta2
-	    j2se_expected_min_size=81 # 83267 kB
+	    j2se_expected_min_size=16 # 16542512 bytes
 	    found=true
 	    ;;
 	"jre-1_5_0-linux-i586.bin") # SUPPORTED
 	    j2se_version=1.5.0+update00
-	    j2se_expected_min_size=85 # 86832 kB
+	    j2se_expected_min_size=16 # 16542512 bytes
 	    found=true
 	    ;;
 	"jre-1_5_0_"[0-9][0-9]"-linux-i586.bin") # SUPPORTED
 	    j2se_version=1.5.0+update${archive_name:10:2}
-	    j2se_expected_min_size=80
+	    j2se_expected_min_size=16 # 16542512 bytes
 	    found=true
 	    ;;
       esac
