@@ -1,9 +1,6 @@
 # Detect product
 function sun_j2sdk_doc_detect() {
   local found=
-  eval $(dpkg-architecture)
-  case "${DEB_BUILD_ARCH:-$DEB_BUILD_GNU_TYPE}" in
-    i386|i386-linux|ia64-linux|amd64|x86_64-linux)
       case "$archive_name" in
 	"j2sdk-1_3_1-doc.zip") # SUPPORTED
 	    j2se_version=1.3.1
@@ -31,8 +28,6 @@ function sun_j2sdk_doc_detect() {
 	    found=true
 	    ;;
       esac
-      ;;
-  esac
   if [[ -n "$found" ]]; then
 	cat << EOF
 
